@@ -1,22 +1,29 @@
-from linux_profile.utils.text import color
-from linux_profile.base.log import run_app
+"""
+Module Error
+"""
 
-LOG_APP = run_app(name_log='app')
+
+from linux_profile.utils.text import color
 
 
 class ErrorLoadSettings(Exception):
 
     def __init__(self):
         message = "It is not possible to load the basic settings."
-        LOG_APP.error(message)
         super(ErrorLoadSettings, self).__init__(message)
 
 
+class ErrorFile(Exception):
+
+    def __init__(self):
+        message = "File error"
+        super(ErrorFile, self).__init__(message)
+
+
 class ErrorOptionIsMissing(Exception):
 
     def __init__(self, parameter):
         message = f"Option [{parameter}] is missing!"
-        LOG_APP.error(message)
         super(ErrorOptionIsMissing, self).__init__(message)
 
 
@@ -24,7 +31,6 @@ class ErrorOptionIsInvalid(Exception):
 
     def __init__(self, parameter, options):
         message = f"Option [{parameter}] invalid! Usage: {str(options)}"
-        LOG_APP.error(message)
         super(ErrorOptionIsInvalid, self).__init__(message)
 
 
@@ -32,7 +38,6 @@ class ErrorInvalidValue(Exception):
 
     def __init__(self, parameter):
         message = f"Option [{parameter}] invalid value!"
-        LOG_APP.error(message)
         super(ErrorInvalidValue, self).__init__(message)
 
 
@@ -40,7 +45,6 @@ class ErrorParameterIsMissing(Exception):
 
     def __init__(self, parameter):
         message = f"Parameter --{parameter} is missing"
-        LOG_APP.error(message)
         super(ErrorParameterIsMissing, self).__init__(message)
 
 
