@@ -1,29 +1,25 @@
-from linux_profile.base.config import BaseConfig
+from linux_profile.base.action import Action
+from linux_profile.base.config import Config
 from linux_profile.handlers.alias import HandlerAlias
 from linux_profile.handlers.script import HandlerScript
 from linux_profile.handlers.package import HandlerPackage
-from linux_profile.base.storage import StorageQuery
 
 
-class Install(BaseConfig):
+class Install(Config):
 
     def setup(self):
-        """
-        Defines the functions that are executed each
+        """Defines the functions that are executed each
         time the class is instantiated.
         """
-        self.add_config()
-        self.load_config()
-        self.load_profile()
         self.command = self.__class__.__name__.lower()
-        self.query = StorageQuery(self.file.get("profile"))
+        self.action = Action(
+            self.join([self.linuxp_path_config, self.linuxp_file_profile]))
 
-        func = f"{self.command }_{self.module}"
-        call = getattr(self, func, self)
-        call()
+        func = self.join(value=[self.command, self.module], separator="_")
+        getattr(self, func, self)()
 
     def install_package(self):
-        data = self.query.deep_search(
+        data = self.action.deep_search(
             module=self.module,
             tag=self.tag,
             key='name',
@@ -31,24 +27,24 @@ class Install(BaseConfig):
         )
         for item in data:
             item["command"] = self.command
-            HandlerPackage(**item, **self.folder)
+            HandlerPackage(sudo=self.sudo, debug=self.debug, **item)
 
     def install_alias(self):
-        data = self.query.deep_search(
+        data = self.action.deep_search(
             module=self.module,
             tag=self.tag,
             key='command',
             value=self.item
         )
         for item in data:
-            HandlerAlias(**item)
+            HandlerAlias(sudo=self.sudo, debug=self.debug, **item)
 
     def install_script(self):
-        data = self.query.deep_search(
+        data = self.action.deep_search(
             module=self.module,
             tag=self.tag,
             key='name',
             value=self.item
         )
         for item in data:
-            HandlerScript(**item, **self.folder)
+            HandlerScript(sudo=self.sudo, debug=self.debug, **item, **dict(temp=self.linuxp_path_temp))
