@@ -1,28 +1,23 @@
-from linux_profile.base.config import BaseConfig
+from linux_profile.base.action import Action
+from linux_profile.base.config import Config
 from linux_profile.utils.text import print_item
-from linux_profile.base.storage import StorageQuery
 
 
-class List(BaseConfig):
+class List(Config):
 
     def setup(self):
-        """
-        Defines the functions that are executed each
+        """Defines the functions that are executed each
         time the class is instantiated.
         """
-        self.add_config()
-        self.load_config()
-        self.load_profile()
         self.command = self.__class__.__name__.lower()
-        self.query = StorageQuery(self.file.get("profile"))
+        self.action = Action(
+            self.join([self.linuxp_path_config, self.linuxp_file_profile]))
 
-        func = f"{self.command }_{self.module}"
-        call = getattr(self, func, self)
-
-        call()
+        func = self.join(value=[self.command, self.module], separator="_")
+        getattr(self, func, self)()
 
     def list_package(self):
-        data = self.query.deep_search(
+        data = self.action.deep_search(
             module=self.module,
             tag=self.tag,
             key='name',
@@ -31,13 +26,14 @@ class List(BaseConfig):
         for item in data:
             print_item(
                 module=self.module,
+                id=item.get("id", "Null"),
                 tag=item.get("tag", "Null"),
                 item=item.get("name", "Null"),
                 description=item.get("description", "No description")
             )
 
     def list_alias(self):
-        data = self.query.deep_search(
+        data = self.action.deep_search(
             module=self.module,
             tag=self.tag,
             key='name',
@@ -46,13 +42,14 @@ class List(BaseConfig):
         for item in data:
             print_item(
                 module=self.module,
+                id=item.get("id", "Null"),
                 tag=item.get("tag", "Null"),
                 item=item.get("name", "Null"),
                 description=item.get("description", "No description")
             )
 
     def list_script(self):
-        data = self.query.deep_search(
+        data = self.action.deep_search(
             module=self.module,
             tag=self.tag,
             key='name',
@@ -61,6 +58,23 @@ class List(BaseConfig):
         for item in data:
             print_item(
                 module=self.module,
+                id=item.get("id", "Null"),
+                tag=item.get("tag", "Null"),
+                item=item.get("name", "Null"),
+                description=item.get("description", "No description")
+            )
+
+    def list_file(self):
+        data = self.action.deep_search(
+            module=self.module,
+            tag=self.tag,
+            key='name',
+            value=self.item
+        )
+        for item in data:
+            print_item(
+                module=self.module,
+                id=item.get("id", "Null"),
                 tag=item.get("tag", "Null"),
                 item=item.get("name", "Null"),
                 description=item.get("description", "No description")
