@@ -13,12 +13,12 @@ class HandlerAlias(System):
         file_system = read_file(path_file=path_file)
         body = get_content(path_file=file_system, separator="=")
 
-        current_alias = f'\nalias {self.command}="{self.body}"'
+        current_alias = f'alias {self.command}="{self.body}"'
 
         rebase_alias = list()
         for item in body:
             if item[5:len(item)] != self.command:
-                new_alias = f'\nalias {item[5:len(item)]}="{body.get(item)}"'
+                new_alias = f'alias {item[5:len(item)]}="{body.get(item)}"'
                 rebase_alias.append(new_alias)
 
         system(f"true > {path_file}")
